@@ -22,6 +22,12 @@
 #  include <config.h>
 #endif
 
+#ifdef HAVE_WINDOWS_H
+#   include <windows.h>
+#endif
+
+#include <GL/glu.h>
+
 #include <simgear/props/props.hxx>
 
 #include <Include/general.hxx>
