@@ -19,7 +19,7 @@
 // along with this program; if not, write to the Free Software
 // Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 //
-// $Id: auto_gui.cxx,v 1.8 2004/02/03 19:34:23 curt Exp $
+// $Id: auto_gui.cxx,v 1.9 2004/05/26 18:15:19 curt Exp $
 
 
 #ifdef HAVE_CONFIG_H
@@ -677,7 +677,7 @@ int NewWaypoint( string Tgt_Alt )
 
       return 1;
 
-  } else if ( current_fixlist->query( TgtAptId, &f ) ) {
+  } else if ( globals->get_fixlist()->query( TgtAptId, &f ) ) {
       SG_LOG( SG_GENERAL, SG_INFO,
               "Adding waypoint (fix) = " << TgtAptId );
 
