@@ -2,7 +2,7 @@
 
  Module:       FGAtmosphere.cpp
  Author:       Jon Berndt
-               Implementation of 1959 Standard Atmosphere added by Tony Peden 
+               Implementation of 1959 Standard Atmosphere added by Tony Peden
  Date started: 11/24/98
  Purpose:      Models the atmosphere
  Called by:    FGSimExec
@@ -35,7 +35,7 @@ HISTORY
 --------------------------------------------------------------------------------
 11/24/98   JSB   Created
 07/23/99   TP    Added implementation of 1959 Standard Atmosphere
-                 Moved calculation of Mach number to FGTranslation
+                 Moved calculation of Mach number to FGPropagate
                  Later updated to '76 model
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 COMMENTS, REFERENCES,  and NOTES
@@ -51,13 +51,13 @@ INCLUDES
 #include "FGState.h"
 #include "FGFDMExec.h"
 #include "FGAircraft.h"
-#include "FGPosition.h"
+#include "FGPropagate.h"
 #include "FGInertial.h"
 #include "FGPropertyManager.h"
 
 namespace JSBSim {
 
-static const char *IdSrc = "$Id: FGAtmosphere.cpp,v 1.17 2004/03/14 14:57:07 ehofman Exp $";
+static const char *IdSrc = "$Id: FGAtmosphere.cpp,v 1.18 2004/06/14 11:40:45 ehofman Exp $";
 static const char *IdHdr = ID_ATMOSPHERE;
 
 /*%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
@@ -86,7 +86,7 @@ FGAtmosphere::FGAtmosphere(FGFDMExec* fdmex) : FGModel(fdmex)
 //   turbType = ttBerndt;
   TurbGain = 0.0;
   TurbRate = 1.0;
-  
+
   bind();
   Debug(0);
 }
@@ -117,9 +117,9 @@ bool FGAtmosphere::InitModel(void)
   temperature=&intTemperature;
   pressure=&intPressure;
   density=&intDensity;
-  
+
   useExternal=false;
-  
+
   return true;
 }
 
@@ -130,9 +130,9 @@ bool FGAtmosphere::Run(void)
   if (!FGModel::Run()) {                 // if false then execute this Run()
     //do temp, pressure, and density first
     if (!useExternal) {
-      h = Position->Geth();
+      h = Propagate->Geth();
       Calculate(h);
-    } 
+    }
 
     if (turbType != ttNone) {
       Turbulence();
@@ -164,13 +164,13 @@ void FGAtmosphere::Calculate(double altitude)
 
   i = lastIndex;
   if (altitude < htab[lastIndex]) {
-    if (altitude <= 0) { 
+    if (altitude <= 0) {
       i = 0;
       altitude=0;
     } else {
        i = lastIndex-1;
        while (htab[i] > altitude) i--;
-    }   
+    }
   } else if (altitude > htab[lastIndex+1]) {
     if (altitude >= htab[7]) {
       i = 7;
@@ -178,8 +178,8 @@ void FGAtmosphere::Calculate(double altitude)
     } else {
       i = lastIndex+1;
       while (htab[i+1] < altitude) i++;
-    }  
-  } 
+    }
+  }
 
   switch(i) {
   case 1:     // 36089 ft.
@@ -231,9 +231,9 @@ void FGAtmosphere::Calculate(double altitude)
     refpress  = 2116.22;    // psf
     //refdens   = 0.00237767;  // slugs/cubic ft.
     break;
-  
+
   }
- 
+
   if (slope == 0) {
     intTemperature = reftemp;
     intPressure = refpress*exp(-Inertial->SLgravity()/(reftemp*Reng)*(altitude-htab[i]));
@@ -250,10 +250,20 @@ void FGAtmosphere::Calculate(double altitude)
 }
 
 //%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+// Return the pressure at an arbitrary altitude and then restore the internal state
 
+double FGAtmosphere::GetPressure(double alt) {
+  Calculate(alt);
+  double p = *pressure;
+  // Reset the internal atmospheric state
+  Run();
+  return(p);
+}
+
+//%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 // square a value, but preserve the original sign
-static inline double 
-square_signed (double value)
+
+static inline double square_signed (double value)
 {
     if (value < 0)
         return value * value * -1;
@@ -261,6 +271,8 @@ square_signed (double value)
         return value * value;
 }
 
+//%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+
 void FGAtmosphere::Turbulence(void)
 {
   switch (turbType) {
@@ -288,18 +300,18 @@ void FGAtmosphere::Turbulence(void)
     vDirection      += vDirectionAccel*rate*State->Getdt();
 
     vDirection.Normalize();
-    
+
                                 // Diminish turbulence within three wingspans
                                 // of the ground
     vTurbulence = TurbGain * Magnitude * vDirection;
-    double HOverBMAC = Position->GetHOverBMAC();
+    double HOverBMAC = Auxiliary->GetHOverBMAC();
     if (HOverBMAC < 3.0)
         vTurbulence *= (HOverBMAC / 3.0) * (HOverBMAC / 3.0);
 
     vTurbulenceGrad = TurbGain*MagnitudeAccel * vDirection;
 
-    vBodyTurbGrad = State->GetTl2b()*vTurbulenceGrad;
-    
+    vBodyTurbGrad = Propagate->GetTl2b()*vTurbulenceGrad;
+
     if (Aircraft->GetWingSpan() > 0) {
       vTurbPQR(eP) = vBodyTurbGrad(eY)/Aircraft->GetWingSpan();
     } else {
@@ -329,7 +341,7 @@ void FGAtmosphere::Turbulence(void)
     vDirectiondAccelDt(eY) = 1 - 2.0*(double(rand())/double(RAND_MAX));
     vDirectiondAccelDt(eZ) = 1 - 2.0*(double(rand())/double(RAND_MAX));
 
-    
+
     MagnitudedAccelDt = 1 - 2.0*(double(rand())/double(RAND_MAX)) - Magnitude;
     MagnitudeAccel    += MagnitudedAccelDt*rate*State->Getdt();
     Magnitude         += MagnitudeAccel*rate*State->Getdt();
@@ -341,16 +353,16 @@ void FGAtmosphere::Turbulence(void)
 
                                 // Diminish z-vector within two wingspans
                                 // of the ground
-    double HOverBMAC = Position->GetHOverBMAC();
+    double HOverBMAC = Auxiliary->GetHOverBMAC();
     if (HOverBMAC < 2.0)
         vDirection(eZ) *= HOverBMAC / 2.0;
 
     vDirection.Normalize();
-    
+
     vTurbulence = TurbGain*Magnitude * vDirection;
     vTurbulenceGrad = TurbGain*MagnitudeAccel * vDirection;
 
-    vBodyTurbGrad = State->GetTl2b()*vTurbulenceGrad;
+    vBodyTurbGrad = Propagate->GetTl2b()*vTurbulenceGrad;
     vTurbPQR(eP) = vBodyTurbGrad(eY)/Aircraft->GetWingSpan();
     if (Aircraft->GetHTailArm() > 0)
       vTurbPQR(eQ) = vBodyTurbGrad(eZ)/Aircraft->GetHTailArm();
@@ -386,7 +398,6 @@ void FGAtmosphere::UseInternal(void) {
   density=&intDensity;
   useExternal=false;
 }
-  
 
 //%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 
@@ -397,8 +408,8 @@ void FGAtmosphere::bind(void)
                        &FGAtmosphere::GetTemperature);
   PropertyManager->Tie("atmosphere/rho-slugs_ft3", this,
                        &FGAtmosphere::GetDensity);
-  PropertyManager->Tie("atmosphere/P-psf", this,
-                       &FGAtmosphere::GetPressure);
+//  PropertyManager->Tie("atmosphere/P-psf", this,
+//                       &FGAtmosphere::GetPressure);
   PropertyManager->Tie("atmosphere/a-fps", this,
                        &FGAtmosphere::GetSoundSpeed);
   PropertyManager->Tie("atmosphere/T-sl-R", this,
@@ -433,7 +444,7 @@ void FGAtmosphere::unbind(void)
 {
   PropertyManager->Untie("atmosphere/T-R");
   PropertyManager->Untie("atmosphere/rho-slugs_ft3");
-  PropertyManager->Untie("atmosphere/P-psf");
+//  PropertyManager->Untie("atmosphere/P-psf");
   PropertyManager->Untie("atmosphere/a-fps");
   PropertyManager->Untie("atmosphere/T-sl-R");
   PropertyManager->Untie("atmosphere/rho-sl-slugs_ft3");
