@@ -44,7 +44,7 @@ INCLUDES
 DEFINITIONS
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%*/
 
-#define ID_NOZZLE "$Id: FGNozzle.h,v 1.4 2004/01/14 22:09:40 curt Exp $";
+#define ID_NOZZLE "$Id: FGNozzle.h,v 1.5 2004/06/14 11:40:45 ehofman Exp $";
 
 /*%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 FORWARD DECLARATIONS
@@ -58,7 +58,7 @@ CLASS DOCUMENTATION
 
 /** Models a rocket nozzle.
     @author Jon S. Berndt
-    @version $Id: FGNozzle.h,v 1.4 2004/01/14 22:09:40 curt Exp $
+    @version $Id: FGNozzle.h,v 1.5 2004/06/14 11:40:45 ehofman Exp $
 */
 
 /*%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
@@ -75,7 +75,9 @@ public:
 
   double Calculate(double CfPc);
   double GetPowerRequired(void);
-  
+  string GetThrusterLabels(int id);
+  string GetThrusterValues(int id);
+
 private:
   double ReverserAngle;
   double PE;
