@@ -45,7 +45,7 @@ INCLUDES
 DEFINITIONS
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%*/
 
-#define ID_ROCKET "$Id: FGRocket.h,v 1.4 2004/01/14 22:09:40 curt Exp $"
+#define ID_ROCKET "$Id: FGRocket.h,v 1.6 2004/06/27 19:35:54 ehofman Exp $"
 
 /*%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 FORWARD DECLARATIONS
@@ -85,7 +85,7 @@ CLASS DOCUMENTATION
     determined.
 
     @author Jon S. Berndt
-    $Id: FGRocket.h,v 1.4 2004/01/14 22:09:40 curt Exp $
+    $Id: FGRocket.h,v 1.6 2004/06/27 19:35:54 ehofman Exp $
     @see FGNozzle,
     FGThruster,
     FGForce,
@@ -103,28 +103,28 @@ class FGRocket : public FGEngine
 public:
   /** Constructor.
       @param exec pointer to JSBSim parent object, the FDM Executive.
-      @param Eng_cfg pointer to the config file object. */
-  FGRocket(FGFDMExec* exec, FGConfigFile* Eng_cfg);
+      @param Eng_cfg pointer to the config file object.
+      @param engine_number engine number */
+  FGRocket(FGFDMExec* exec, FGConfigFile* Eng_cfg, int engine_number);
 
   /** Destructor */
   ~FGRocket(void);
 
   /** Determines the thrust coefficient.
-      This routine takes the nozzle exit pressure and calculates the thrust
-      coefficient times the chamber pressure.
-      @param pe nozzle exit pressure
       @return thrust coefficient times chamber pressure */
-  double Calculate(double pe);
-  
+  double Calculate(void);
+
   /** Gets the chamber pressure.
       @return chamber pressure in psf. */
   double GetChamberPressure(void) {return PC;}
 
   /** Gets the flame-out status.
-      The engine will "flame out" if the throttle is set below the minimum 
+      The engine will "flame out" if the throttle is set below the minimum
       sustainable setting.
       @return true if engine has flamed out. */
   bool GetFlameout(void) {return Flameout;}
+  string GetEngineLabels(void);
+  string GetEngineValues(void);
 
 private:
   double SHR;
