@@ -9,11 +9,11 @@ class ControlMap {
 public:
     ~ControlMap();
 
-    enum OutputType { THROTTLE, MIXTURE, STARTER, MAGNETOS,
+    enum OutputType { THROTTLE, MIXTURE, CONDLEVER, STARTER, MAGNETOS,
 		      ADVANCE, REHEAT, PROP,
 		      BRAKE, STEER, EXTEND,
 		      INCIDENCE, FLAP0, FLAP1, SLAT, SPOILER, VECTOR,
-                      BOOST, CASTERING, PROPPITCH, 
+                      BOOST, CASTERING, PROPPITCH, PROPFEATHER,
                       COLLECTIVE, CYCLICAIL, CYCLICELE, ROTORENGINEON,
                       REVERSE_THRUST };
 
