@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  *
- * $Id: gui.h,v 1.7 2003/09/24 17:20:56 ehofman Exp $
+ * $Id: gui.h,v 1.9 2004/04/30 08:44:35 ehofman Exp $
  **************************************************************************/
 
 
@@ -33,9 +33,7 @@
 #  include <windows.h>
 #endif
 
-#include FG_GLUT_H              // needed before pu.h
-
-#include <plib/pu.h>		// plib include
+#include <plib/pu.h>
 
 #include <simgear/structure/exception.hxx>
 
