@@ -18,9 +18,10 @@
 // along with this program; if not, write to the Free Software
 // Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 //
-// $Id: globals.cxx,v 1.20 2004/01/31 19:47:46 curt Exp $
+// $Id: globals.cxx,v 1.29 2004/07/16 20:02:36 ehofman Exp $
 
 
+#include <simgear/sound/soundmgr_openal.hxx>
 #include <simgear/structure/commands.hxx>
 #include <simgear/misc/sg_path.hxx>
 
@@ -45,7 +46,6 @@ FGGlobals::FGGlobals() :
     event_mgr( new SGEventMgr ),
     sim_time_sec( 0.0 ),
     fg_root( "" ),
-    fg_scenery( "" ),
 #if defined(FX) && defined(XMESA)
     fullscreen( true ),
 #endif
@@ -71,9 +71,16 @@ FGGlobals::FGGlobals() :
     acmodel( NULL ),
     model_mgr( NULL ),
     channel_options_list( NULL ),
+    initial_waypoints( NULL ),
     scenery( NULL ),
     tile_mgr( NULL ),
-    io( new FGIO )
+    io( new FGIO ),
+    navlist( NULL ),
+    loclist( NULL ),
+    gslist( NULL ),
+    dmelist( NULL ),
+    mkrlist( NULL ),
+    fixlist( NULL )
 {
 }
 
@@ -81,12 +88,18 @@ FGGlobals::FGGlobals() :
 // Destructor
 FGGlobals::~FGGlobals() 
 {
-  delete subsystem_mgr;
-  delete event_mgr;
-  delete initial_state;
-  delete props;
-  delete commands;
-  delete io;
+    delete soundmgr;
+    delete subsystem_mgr;
+    delete event_mgr;
+    delete initial_state;
+    delete props;
+    delete commands;
+    delete io;
+  
+    // make sure only to delete the initial waypoints list if it acually
+    // still exists. 
+    if (initial_waypoints)
+        delete initial_waypoints;
 }
 
 
@@ -103,6 +116,46 @@ void FGGlobals::set_fg_root (const string &root) {
         }
 }
 
+void FGGlobals::set_fg_scenery (const string &scenery) {
+    SGPath s;
+    if (scenery.empty()) {
+        s.set( fg_root );
+        s.append( "Scenery" );
+    } else
+        s.set( scenery );
+
+    string_list path_list = sgPathSplit( s.str() );
+    fg_scenery.clear();
+
+    for (unsigned i = 0; i < path_list.size(); i++) {
+
+        ulDir *d = ulOpenDir( path_list[i].c_str() );
+        if (d == NULL)
+            continue;
+        ulCloseDir( d );
+
+        SGPath pt( path_list[i] ), po( path_list[i] );
+        pt.append("Terrain");
+        po.append("Objects");
+
+        ulDir *td = ulOpenDir( pt.c_str() );
+        ulDir *od = ulOpenDir( po.c_str() );
+
+        if (td == NULL && od == NULL)
+            fg_scenery.push_back( path_list[i] );
+        else {
+            if (td != NULL) {
+                fg_scenery.push_back( pt.str() );
+                ulCloseDir( td );
+            }
+            if (od != NULL) {
+                fg_scenery.push_back( po.str() );
+                ulCloseDir( od );
+            }
+        }
+    }
+}
+
 
 SGSubsystemMgr *
 FGGlobals::get_subsystem_mgr () const
