@@ -18,7 +18,7 @@
 // along with this program; if not, write to the Free Software
 // Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 //
-// $Id: main.cxx,v 1.151 2004/03/19 03:30:18 curt Exp $
+// $Id: main.cxx,v 1.175 2004/07/29 21:54:15 curt Exp $
 
 
 #ifdef HAVE_CONFIG_H
@@ -42,7 +42,6 @@
 #endif
 
 #include <plib/ssg.h>
-#include <plib/pu.h>
 #include <plib/netSocket.h>
 
 #include <simgear/screen/extensions.hxx>
@@ -85,6 +84,7 @@
 #include <Time/tmp.hxx>
 #include <Time/fg_timer.hxx>
 #include <Environment/environment_mgr.hxx>
+#include <GUI/new_gui.hxx>
 
 #ifdef FG_MPLAYER_AS
 #include <MultiPlayer/multiplaytxmgr.hxx>
@@ -127,7 +127,7 @@ bool glPointParameterIsSupported = false;
 FGGeneral general;
 
 // Specify our current idle function state.  This is used to run all
-// our initializations out of the glutIdleLoop() so that we can get a
+// our initializations out of the idle callback so that we can get a
 // splash screen up and running right away.
 static int idle_state = 0;
 static long global_multi_loop;
@@ -159,27 +159,6 @@ sgMat4 copy_of_ssgOpenGLAxisSwapMatrix =
   {  0.0f,  0.0f,  0.0f,  1.0f }
 };
 
-// The following defines flightgear options. Because glutlib will also
-// want to parse its own options, those options must not be included here
-// or they will get parsed by the main program option parser. Hence case
-// is significant for any option added that might be in conflict with
-// glutlib's parser.
-//
-// glutlib parses for:
-//    -display
-//    -direct   (invalid in Win32)
-//    -geometry
-//    -gldebug
-//    -iconized
-//    -indirect (invalid in Win32)
-//    -synce
-//
-// Note that glutlib depends upon strings while this program's
-// option parser wants only initial characters followed by numbers
-// or pathnames.
-//
-
-
 ssgSimpleState *cloud3d_imposter_state;
 ssgSimpleState *default_state;
 ssgSimpleState *hud_and_panel;
@@ -236,12 +215,10 @@ void fgInitVisuals( void ) {
 
     FGLight *l = (FGLight *)(globals->get_subsystem("lighting"));
 
-#ifndef GLUT_WRONG_VERSION
     // Go full screen if requested ...
     if ( fgGetBool("/sim/startup/fullscreen") ) {
-        glutFullScreen();
+        fgOSFullScreen();
     }
-#endif
 
     // If enabled, normal vectors specified with glNormal are scaled
     // to unit length after transformation.  Enabling this has
@@ -281,6 +258,13 @@ void fgInitVisuals( void ) {
 
 // For HiRes screen Dumps using Brian Pauls TR Library
 void trRenderFrame( void ) {
+#ifdef FG_ENABLE_MULTIPASS_CLOUDS
+    bool multi_pass_clouds = fgGetBool("/sim/rendering/multi-pass-clouds") &&
+                            !SGCloudLayer::enable_bump_mapping; // ugly artefact now
+#else
+    bool multi_pass_clouds = false;
+#endif
+    bool draw_clouds = fgGetBool("/environment/clouds/status");
 
     if ( fgPanelVisible() ) {
         GLfloat height = fgGetInt("/sim/startup/ysize");
@@ -323,14 +307,43 @@ void trRenderFrame( void ) {
 
     // we need a white diffuse light for the phase of the moon
     ssgGetLight( 0 ) -> setColour( GL_DIFFUSE, white );
-    thesky->preDraw( cur_fdm_state->get_Altitude() * SG_FEET_TO_METER, fog_exp2_density );
+    thesky->preDraw( cur_fdm_state->get_Altitude() * SG_FEET_TO_METER,
+                     fog_exp2_density );
 
     // draw the ssg scene
     // return to the desired diffuse color
     ssgGetLight( 0 ) -> setColour( GL_DIFFUSE, l->scene_diffuse() );
     glEnable( GL_DEPTH_TEST );
     ssgSetNearFar( scene_nearplane, scene_farplane );
-    ssgCullAndDraw( globals->get_scenery()->get_scene_graph() );
+    if ( draw_clouds ) {
+        // Draw the terrain
+        FGTileMgr::set_tile_filter( true );
+        sgSetModelFilter( false );
+        globals->get_aircraft_model()->select( false );
+        ssgCullAndDraw( globals->get_scenery()->get_scene_graph() );
+        // Disable depth buffer update, draw the clouds
+        glDepthMask( GL_FALSE );
+        thesky->drawUpperClouds();
+        if ( multi_pass_clouds ) {
+            thesky->drawLowerClouds();
+        }
+        glDepthMask( GL_TRUE );
+        if ( multi_pass_clouds ) {
+            // Draw the objects except the aircraft
+            //  and update the stencil buffer with 1
+            glEnable( GL_STENCIL_TEST );
+            glStencilFunc( GL_ALWAYS, 1, 1 );
+            glStencilOp( GL_KEEP, GL_KEEP, GL_REPLACE );
+        }
+        FGTileMgr::set_tile_filter( false );
+        sgSetModelFilter( true );
+        ssgCullAndDraw( globals->get_scenery()->get_scene_graph() );
+    } else {
+        FGTileMgr::set_tile_filter( true );
+        sgSetModelFilter( true );
+        globals->get_aircraft_model()->select( false );
+        ssgCullAndDraw( globals->get_scenery()->get_scene_graph() );
+    }
 
     // draw the lights
     glFogf (GL_FOG_DENSITY, rwy_exp2_punch_through);
@@ -340,9 +353,26 @@ void trRenderFrame( void ) {
 
     ssgCullAndDraw( globals->get_scenery()->get_gnd_lights_root() );
 
-    if (fgGetBool("/environment/clouds/status"))
-        thesky->postDraw( cur_fdm_state->get_Altitude() * SG_FEET_TO_METER );
+    if ( draw_clouds ) {
+        if ( multi_pass_clouds ) {
+            // Disable depth buffer update, draw the clouds where the
+            //  objects overwrite the already drawn clouds, by testing
+            //  the stencil buffer against 1
+            glDepthMask( GL_FALSE );
+            glStencilFunc( GL_EQUAL, 1, 1 );
+            glStencilOp( GL_KEEP, GL_KEEP, GL_KEEP );
+            thesky->drawUpperClouds();
+            thesky->drawLowerClouds();
+            glDepthMask( GL_TRUE );
+            glDisable( GL_STENCIL_TEST );
+        } else {
+            glDepthMask( GL_FALSE );
+            thesky->drawLowerClouds();
+            glDepthMask( GL_TRUE );
+        }
+    }
 
+    globals->get_aircraft_model()->select( true );
     globals->get_model_mgr()->draw();
     globals->get_aircraft_model()->draw();
 }
@@ -354,6 +384,13 @@ void fgRenderFrame() {
     bool skyblend = fgGetBool("/sim/rendering/skyblend");
     bool enhanced_lighting = fgGetBool("/sim/rendering/enhanced-lighting");
     bool distance_attenuation = fgGetBool("/sim/rendering/distance-attenuation");
+#ifdef FG_ENABLE_MULTIPASS_CLOUDS
+    bool multi_pass_clouds = fgGetBool("/sim/rendering/multi-pass-clouds") && 
+                                !SGCloudLayer::enable_bump_mapping;  // ugly artefact now
+#else
+    bool multi_pass_clouds = false;
+#endif
+    bool draw_clouds = fgGetBool("/environment/clouds/status");
 
     GLfloat black[4] = { 0.0, 0.0, 0.0, 1.0 };
     GLfloat white[4] = { 1.0, 1.0, 1.0, 1.0 };
@@ -458,6 +495,10 @@ void fgRenderFrame() {
                          l->sky_color()[2], l->sky_color()[3]);
             clear_mask |= GL_COLOR_BUFFER_BIT;
         }
+        if ( multi_pass_clouds && draw_clouds ) {
+            glClearStencil( 0 );
+            clear_mask |= GL_STENCIL_BUFFER_BIT;
+        }
         glClear( clear_mask );
 
         // Tell GL we are switching to model view parameters
@@ -621,15 +662,13 @@ void fgRenderFrame() {
         globals->get_multiplayer_rx_mgr()->Update();
 #endif
 
-        if ( draw_otw && skyblend )
-        {
+        if ( draw_otw && skyblend ) {
             // draw the sky backdrop
 
             // we need a white diffuse light for the phase of the moon
             ssgGetLight( 0 ) -> setColour( GL_DIFFUSE, white );
-
-            thesky->preDraw( cur_fdm_state->get_Altitude() * SG_FEET_TO_METER, fog_exp2_density );
-
+            thesky->preDraw( cur_fdm_state->get_Altitude() * SG_FEET_TO_METER,
+                             fog_exp2_density );
             // return to the desired diffuse color
             ssgGetLight( 0 ) -> setColour( GL_DIFFUSE, l->scene_diffuse() );
         }
@@ -644,7 +683,38 @@ void fgRenderFrame() {
             glPolygonMode( GL_FRONT_AND_BACK, GL_LINE );
         }
         if ( draw_otw ) {
-            ssgCullAndDraw( globals->get_scenery()->get_scene_graph() );
+            if ( draw_clouds ) {
+
+                // Draw the terrain
+                FGTileMgr::set_tile_filter( true );
+                sgSetModelFilter( false );
+                globals->get_aircraft_model()->select( false );
+                ssgCullAndDraw( globals->get_scenery()->get_scene_graph() );
+
+                // Disable depth buffer update, draw the clouds
+                glDepthMask( GL_FALSE );
+                thesky->drawUpperClouds();
+                if ( multi_pass_clouds ) {
+                    thesky->drawLowerClouds();
+                }
+                glDepthMask( GL_TRUE );
+
+                if ( multi_pass_clouds ) {
+                    // Draw the objects except the aircraft
+                    //  and update the stencil buffer with 1
+                    glEnable( GL_STENCIL_TEST );
+                    glStencilFunc( GL_ALWAYS, 1, 1 );
+                    glStencilOp( GL_KEEP, GL_KEEP, GL_REPLACE );
+                }
+                FGTileMgr::set_tile_filter( false );
+                sgSetModelFilter( true );
+                ssgCullAndDraw( globals->get_scenery()->get_scene_graph() );
+            } else {
+                FGTileMgr::set_tile_filter( true );
+                sgSetModelFilter( true );
+                globals->get_aircraft_model()->select( false );
+                ssgCullAndDraw( globals->get_scenery()->get_scene_graph() );
+            }
         }
 
         // This is a bit kludgy.  Every 200 frames, do an extra
@@ -655,16 +725,18 @@ void fgRenderFrame() {
         static int counter = 0;
         counter++;
         if (counter == 200) {
-          sgFrustum f;
-          f.setFOV(360, 360);
-                            // No need to put the near plane too close;
-                            // this way, at least the aircraft can be
-                            // culled.
-          f.setNearFar(1000, 1000000);
-          sgMat4 m;
-          ssgGetModelviewMatrix(m);
-          globals->get_scenery()->get_scene_graph()->cull(&f, m, true);
-          counter = 0;
+            sgFrustum f;
+            f.setFOV(360, 360);
+                    // No need to put the near plane too close;
+                    // this way, at least the aircraft can be
+                    // culled.
+            f.setNearFar(1000, 1000000);
+            sgMat4 m;
+            ssgGetModelviewMatrix(m);
+            FGTileMgr::set_tile_filter( true );
+            sgSetModelFilter( true );
+            globals->get_scenery()->get_scene_graph()->cull(&f, m, true);
+            counter = 0;
         }
 
         // change state for lighting here
@@ -732,8 +804,7 @@ void fgRenderFrame() {
 
 
         if ( enhanced_lighting ) {
-            if ( distance_attenuation && glPointParameterIsSupported )
-            {
+            if ( distance_attenuation && glPointParameterIsSupported ) {
                 glPointParameterfvPtr(GL_DISTANCE_ATTENUATION_EXT,
                                       default_attenuation);
             }
@@ -748,17 +819,7 @@ void fgRenderFrame() {
             ssgCullAndDraw( globals->get_scenery()->get_gnd_lights_root() );
         }
 
-        if ( skyblend ) {
-            // draw the sky cloud layers
-            if ( draw_otw && fgGetBool("/environment/clouds/status") )
-            {
-                thesky->postDraw( cur_fdm_state->get_Altitude()
-                                  * SG_FEET_TO_METER );
-            }
-        }
-
-        if ( draw_otw && fgGetBool("/sim/rendering/clouds3d") )
-        {
+        if ( draw_otw && fgGetBool("/sim/rendering/clouds3d") ) {
             glDisable( GL_FOG );
             glDisable( GL_LIGHTING );
             // cout << "drawing new clouds" << endl;
@@ -784,9 +845,40 @@ void fgRenderFrame() {
             glBlendFunc ( GL_SRC_ALPHA, GL_ONE_MINUS_SRC_ALPHA ) ;
         }
 
+        if ( draw_otw && draw_clouds ) {
+            if ( multi_pass_clouds ) {
+                // Disable depth buffer update, draw the clouds where the
+                //  objects overwrite the already drawn clouds, by testing
+                //  the stencil buffer against 1
+                glDepthMask( GL_FALSE );
+                glStencilFunc( GL_EQUAL, 1, 1 );
+                glStencilOp( GL_KEEP, GL_KEEP, GL_KEEP );
+                thesky->drawUpperClouds();
+                thesky->drawLowerClouds();
+                glDepthMask( GL_TRUE );
+                glDisable( GL_STENCIL_TEST );
+            } else {
+                glDepthMask( GL_FALSE );
+                thesky->drawLowerClouds();
+                glDepthMask( GL_TRUE );
+            }
+        }
+
         if ( draw_otw ) {
+            FGTileMgr::set_tile_filter( false );
+            sgSetModelFilter( false );
+            globals->get_aircraft_model()->select( true );
             globals->get_model_mgr()->draw();
             globals->get_aircraft_model()->draw();
+            // If the view is internal, the previous line draw the 
+            //  cockpit with modified near/far clip planes and deselect
+            //  the aircraft in the global scenegraph
+            // Otherwise, it just enables the aircraft: The scenegraph
+            //  must be drawn again to see the plane.
+            ssgCullAndDraw( globals->get_scenery()->get_scene_graph() );
+            FGTileMgr::set_tile_filter( true );
+            sgSetModelFilter( true );
+            globals->get_aircraft_model()->select( true );
         }
 
         // display HUD && Panel
@@ -829,8 +921,6 @@ void fgRenderFrame() {
             fgSplashUpdate(0.0, (3.0 - t) / 2.0);
         }
     }
-
-    glutSwapBuffers();
 }
 
 
@@ -844,8 +934,8 @@ void fgUpdateTimeDepCalcs() {
         = fgGetNode( "/sim/freeze/replay", true );
     static SGPropertyNode *replay_time
         = fgGetNode( "/sim/replay/time", true );
-    static const SGPropertyNode *replay_end_time
-        = fgGetNode( "/sim/replay/end-time", true );
+    // static const SGPropertyNode *replay_end_time
+    //     = fgGetNode( "/sim/replay/end-time", true );
 
     //SG_LOG(SG_FLIGHT,SG_INFO, "Updating time dep calcs()");
 
@@ -928,8 +1018,10 @@ static void fgMainLoop( void ) {
         = fgGetNode("/sim/freeze/clock", true);
     static const SGPropertyNode *cur_time_override
         = fgGetNode("/sim/time/cur-time-override", true);
-    static const SGPropertyNode *replay_master
-        = fgGetNode("/sim/freeze/replay", true);
+    // static const SGPropertyNode *replay_master
+    //     = fgGetNode("/sim/freeze/replay", true);
+
+    SGCloudLayer::enable_bump_mapping = fgGetBool("/sim/rendering/bump-mapping",true);
 
     // Update the elapsed time.
     static bool first_time = true;
@@ -989,10 +1081,6 @@ static void fgMainLoop( void ) {
     // {
     //    fgJoystickRead();
     // }
-#elif defined( ENABLE_GLUT_JOYSTICK )
-    // Glut joystick support works by feeding a joystick handler
-    // function to glut.  This is taken care of once in the joystick
-    // init routine and we don't have to worry about it again.
 #endif
 
     // Fix elevation.  I'm just sticking this here for now, it should
@@ -1118,8 +1206,16 @@ static void fgMainLoop( void ) {
     }
 
     // flight model
-    if ( global_multi_loop > 0 ) {
-        fgUpdateTimeDepCalcs();
+    if ( global_multi_loop > 0) {
+        // first run the flight model each frame until it is intialized
+        // then continue running each frame only after initial scenery load is complete.
+        if (!cur_fdm_state->get_inited() || fgGetBool("sim/sceneryloaded")) {
+            fgUpdateTimeDepCalcs();
+        } else {
+            // only during scenery load
+            NewGUI * gui = (NewGUI *)globals->get_subsystem("gui");
+            gui->showDialog("scenery_loading");
+        }
     } else {
         SG_LOG( SG_ALL, SG_DEBUG, 
             "Elapsed time is zero ... we're zinging" );
@@ -1133,8 +1229,7 @@ static void fgMainLoop( void ) {
 
     // Run audio scheduler
 #ifdef ENABLE_AUDIO_SUPPORT
-    if ( fgGetBool("/sim/sound/audible")
-           && globals->get_soundmgr()->is_working() ) {
+    if ( globals->get_soundmgr()->is_working() ) {
         globals->get_soundmgr()->update( delta_time_sec );
     }
 #endif
@@ -1150,58 +1245,107 @@ static void fgMainLoop( void ) {
     FGViewer *current_view = globals->get_current_view();
 
     // get the location data for the primary FDM (now hardcoded to ac model)...
-    SGLocation * acmodel_location = 0;
-    acmodel_location = (SGLocation *)  globals->get_aircraft_model()->get3DModel()->getSGLocation();
+    SGLocation *acmodel_loc = NULL;
+    acmodel_loc = (SGLocation *)globals->
+        get_aircraft_model()->get3DModel()->getSGLocation();
 
     // update tile manager for FDM...
-    // ...only if location is different than the current-view location (to avoid duplicating effort)
+    // ...only if location is different than the current-view location
+    // (to avoid duplicating effort)
     if( !fgGetBool("/sim/current-view/config/from-model") ) {
-      if( acmodel_location != 0 ) {
-        globals->get_tile_mgr()->prep_ssg_nodes( acmodel_location,
-                                                 visibility_meters );
-        globals->get_tile_mgr()->
-            update( acmodel_location, visibility_meters,
-                    acmodel_location->get_absolute_view_pos(globals->get_scenery()->get_center()) );
-        // save results of update in SGLocation for fdm...
-        if ( globals->get_scenery()->get_cur_elev() > -9990 ) {
-          acmodel_location->
-              set_cur_elev_m( globals->get_scenery()->get_cur_elev() );
-          fgSetDouble("/position/ground-elev-m", globals->get_scenery()->get_cur_elev());
+        if( acmodel_loc != NULL ) {
+            globals->get_tile_mgr()->prep_ssg_nodes( acmodel_loc,
+                                                     visibility_meters );
+            globals->get_tile_mgr()->
+                update( acmodel_loc, visibility_meters,
+                        acmodel_loc->
+                        get_absolute_view_pos(globals->
+                                              get_scenery()->get_center()) );
+            // save results of update in SGLocation for fdm...
+            if ( globals->get_scenery()->get_cur_elev() > -9990 ) {
+                acmodel_loc->
+                    set_cur_elev_m( globals->get_scenery()->get_cur_elev() );
+                fgSetDouble("/position/ground-elev-m",
+                            globals->get_scenery()->get_cur_elev());
+            }
+            acmodel_loc->
+                set_tile_center( globals->get_scenery()->get_next_center() );
         }
-        acmodel_location->
-            set_tile_center( globals->get_scenery()->get_next_center() );
-      }
     }
 
     globals->get_tile_mgr()->prep_ssg_nodes( current_view->getSGLocation(),
                                              visibility_meters );
     // update tile manager for view...
-    // IMPORTANT!!! the tilemgr update for view location _must_ be done last 
-    // after the FDM's until all of Flight Gear code references the viewer's location
-    // for elevation instead of the "scenery's" current elevation.
+    // IMPORTANT!!! the tilemgr update for view location _must_ be
+    // done last after the FDM's until all of Flight Gear code
+    // references the viewer's location for elevation instead of the
+    // "scenery's" current elevation.
     SGLocation *view_location = globals->get_current_view()->getSGLocation();
     globals->get_tile_mgr()->update( view_location, visibility_meters,
                                      current_view->get_absolute_view_pos() );
     // save results of update in SGLocation for fdm...
     if ( globals->get_scenery()->get_cur_elev() > -9990 ) {
-      current_view->getSGLocation()->set_cur_elev_m( globals->get_scenery()->get_cur_elev() );
+        current_view->getSGLocation()->
+            set_cur_elev_m( globals->get_scenery()->get_cur_elev() );
     }
-    current_view->getSGLocation()->set_tile_center( globals->get_scenery()->get_next_center() );
+    current_view->getSGLocation()->
+        set_tile_center( globals->get_scenery()->get_next_center() );
 
-    // If fdm location is same as viewer's then we didn't do the update for fdm location 
-    //   above so we need to save the viewer results in the fdm SGLocation as well...
+#ifdef ENABLE_AUDIO_SUPPORT
+    // Right now we make a simplifying assumption that the primary
+    // aircraft is the source of all sounds and that all sounds are
+    // positioned relative to the current view position.
+
+    static sgVec3 last_pos_offset;
+
+    // set positional offset for sources
+    sgVec3 source_pos_offset;
+    sgSubVec3( source_pos_offset,
+               view_location->get_view_pos(), acmodel_loc->get_view_pos() );
+    // cout << "pos all = " << source_pos_offset[0] << " " << source_pos_offset[1] << " " << source_pos_offset[2] << endl;
+    globals->get_soundmgr()->set_source_pos_all( source_pos_offset );
+
+    // set the velocity
+    sgVec3 source_vel;
+    sgSubVec3( source_vel, source_pos_offset, last_pos_offset );
+    sgScaleVec3( source_vel, delta_time_sec );
+    sgCopyVec3( last_pos_offset, source_pos_offset );
+    // cout << "vel = " << source_vel[0] << " " << source_vel[1] << " " << source_vel[2] << endl;
+    globals->get_soundmgr()->set_source_vel_all( source_vel );
+
+    // Right now we make a simplifying assumption that the listener is
+    // always positioned at the origin.
+    sgVec3 listener_pos;
+    sgSetVec3( listener_pos, 0.0, 0.0, 0.0 );
+    // cout << "listener = " << listener_pos[0] << " " << listener_pos[1] << " " << listener_pos[2] << endl;
+    globals->get_soundmgr()->set_listener_pos( listener_pos );
+#endif
+
+    // If fdm location is same as viewer's then we didn't do the
+    // update for fdm location above so we need to save the viewer
+    // results in the fdm SGLocation as well...
     if( fgGetBool("/sim/current-view/config/from-model") ) {
-      if( acmodel_location != 0 ) {
-        if ( globals->get_scenery()->get_cur_elev() > -9990 ) {
-          acmodel_location->set_cur_elev_m( globals->get_scenery()->get_cur_elev() );
-          fgSetDouble("/position/ground-elev-m", globals->get_scenery()->get_cur_elev());
+        if( acmodel_loc != 0 ) {
+            if ( globals->get_scenery()->get_cur_elev() > -9990 ) {
+                acmodel_loc->set_cur_elev_m( globals->get_scenery()->
+                                             get_cur_elev() );
+                fgSetDouble("/position/ground-elev-m",
+                            globals->get_scenery()->get_cur_elev());
+            }
+            acmodel_loc->set_tile_center( globals->get_scenery()->
+                                          get_next_center() );
         }
-        acmodel_location->set_tile_center( globals->get_scenery()->get_next_center() );
-      }
     }
 
     // END Tile Manager udpates
 
+    if (!fgGetBool("sim/sceneryloaded") && globals->get_tile_mgr()->all_queues_empty() && cur_fdm_state->get_inited()) {
+        fgSetBool("sim/sceneryloaded",true);
+        // probably not efficient way to popup msg,  but is done only during scenery load
+        NewGUI * gui = (NewGUI *)globals->get_subsystem("gui");
+        gui->closeDialog("scenery_loading");
+    }
+
     if (fgGetBool("/sim/rendering/specular-highlight")) {
         glLightModeli(GL_LIGHT_MODEL_COLOR_CONTROL, GL_SEPARATE_SPECULAR_COLOR);
 	// glLightModeli(GL_LIGHT_MODEL_TWO_SIDE, GL_TRUE);
@@ -1210,8 +1354,7 @@ static void fgMainLoop( void ) {
         // glLightModeli(GL_LIGHT_MODEL_TWO_SIDE, GL_FALSE);
     }
 
-    // redraw display
-    fgRenderFrame();
+    fgRequestRedraw();
 
     SG_LOG( SG_ALL, SG_DEBUG, "" );
 }
@@ -1228,6 +1371,8 @@ static void fgIdleFunction ( void ) {
     // printf("idle state == %d\n", idle_state);
 
     if ( idle_state == 0 ) {
+        fgSetBool("sim/initialised", false);
+
         // Initialize the splash screen right away
         if ( fgGetBool("/sim/startup/splash-screen") ) {
             fgSplashInit(fgGetString("/sim/startup/splash-texture"));
@@ -1311,8 +1456,10 @@ static void fgIdleFunction ( void ) {
     if ( idle_state == 1000 ) {
         // We've finished all our initialization steps, from now on we
         // run the main loop.
+        fgSetBool("sim/initialised",true);
+        fgSetBool("sim/sceneryloaded",false);
 
-        glutIdleFunc(fgMainLoop);
+        fgRegisterIdleHandler(fgMainLoop);
     } else {
         if ( fgGetBool("/sim/startup/splash-screen") ) {
             fgSplashUpdate(0.0, 1.0);
@@ -1360,110 +1507,15 @@ void fgReshape( int width, int height ) {
 
 }
 
-// Initialize GLUT and define a main window
-static bool fgGlutInit( int *argc, char **argv ) {
 
-#if !defined( macintosh )
-    // GLUT will extract all glut specific options so later on we only
-    // need wory about our own.
-    glutInit(argc, argv);
-#endif
-
-    // Define Display Parameters. Clouds3d works best with --bpp32 option
-    if ( fgGetBool("/sim/rendering/clouds3d") ) {
-        glutInitDisplayMode( GLUT_RGB | GLUT_DEPTH | GLUT_DOUBLE | GLUT_ALPHA );
-    } else {
-        glutInitDisplayMode( GLUT_RGB | GLUT_DEPTH | GLUT_DOUBLE );
-    }
-
-    SG_LOG( SG_GENERAL, SG_INFO, "Opening a window: " <<
-            fgGetInt("/sim/startup/xsize") << "x"
-            << fgGetInt("/sim/startup/ysize") );
-
-    // Define initial window size
-    glutInitWindowSize( fgGetInt("/sim/startup/xsize"),
-                    fgGetInt("/sim/startup/ysize") );
-
-    // Initialize windows
-    if ( !fgGetBool("/sim/startup/game-mode")) {
-        // Open the regular window
-        glutCreateWindow("FlightGear");
-#ifndef GLUT_WRONG_VERSION
-    } else {
-        // Open the cool new 'game mode' window
-        char game_mode_str[256];
-//#define SYNC_OPENGL_WITH_DESKTOP_SETTINGS
-#if defined(WIN32) && defined(SYNC_OPENGL_WITH_DESKTOP_SETTINGS)
-#ifndef ENUM_CURRENT_SETTINGS
-#define ENUM_CURRENT_SETTINGS       ((DWORD)-1)
-#define ENUM_REGISTRY_SETTINGS      ((DWORD)-2)
-#endif
-
-        DEVMODE dm;
-        dm.dmSize = sizeof(DEVMODE);
-        EnumDisplaySettings(NULL, ENUM_CURRENT_SETTINGS, &dm);
-        fgSetInt("/sim/startup/xsize", dm.dmPelsWidth);
-        fgSetInt("/sim/startup/ysize", dm.dmPelsHeight);
-        glutInitWindowSize( fgGetInt("/sim/startup/xsize"),
-                            fgGetInt("/sim/startup/ysize") );
-        sprintf( game_mode_str, "%dx%d:%d@%d",
-                     dm.dmPelsWidth,
-                     dm.dmPelsHeight,
-                     dm.dmBitsPerPel,
-                     dm.dmDisplayFrequency );
-#else
-        // Open the cool new 'game mode' window
-        sprintf( game_mode_str, "width=%d height=%d bpp=%d",
-             fgGetInt("/sim/startup/xsize"),
-             fgGetInt("/sim/startup/ysize"),
-             fgGetInt("/sim/rendering/bits-per-pixel"));
-
-#endif // HAVE_WINDOWS_H
-        SG_LOG( SG_GENERAL, SG_INFO, 
-            "game mode params = " << game_mode_str );
-        glutGameModeString( game_mode_str );
-        glutEnterGameMode();
-#endif // GLUT_WRONG_VERSION
-    }
-
-    // This seems to be the absolute earliest in the init sequence
-    // that these calls will return valid info.  Too bad it's after
-    // we've already created and sized out window. :-(
-    general.set_glVendor( (char *)glGetString ( GL_VENDOR ) );
-    general.set_glRenderer( (char *)glGetString ( GL_RENDERER ) );
-    general.set_glVersion( (char *)glGetString ( GL_VERSION ) );
-    SG_LOG( SG_GENERAL, SG_INFO, general.get_glRenderer() );
-
-    GLint tmp;
-    glGetIntegerv( GL_MAX_TEXTURE_SIZE, &tmp );
-    general.set_glMaxTexSize( tmp );
-    SG_LOG ( SG_GENERAL, SG_INFO, "Max texture size = " << tmp );
-
-    glGetIntegerv( GL_DEPTH_BITS, &tmp );
-    general.set_glDepthBits( tmp );
-    SG_LOG ( SG_GENERAL, SG_INFO, "Depth buffer bits = " << tmp );
-
-    return true;
+// do some clean up on exit.  Specifically we want to call alutExit()
+// which happens in the sound manager destructor.
+void fgExitCleanup() {
+    delete globals;
+//    fgOSExit(0);
 }
 
 
-// Initialize GLUT event handlers
-static bool fgGlutInitEvents( void ) {
-    // call fgReshape() on window resizes
-    glutReshapeFunc( fgReshape );
-
-    // keyboard and mouse callbacks are set in FGInput::init
-
-    // call fgMainLoop() whenever there is
-    // nothing else to do
-    glutIdleFunc( fgIdleFunction );
-
-    // draw the scene
-    glutDisplayFunc( fgRenderFrame );
-
-    return true;
-}
-
 // Main top level initialization
 bool fgMainInit( int argc, char **argv ) {
 
@@ -1476,6 +1528,8 @@ bool fgMainInit( int argc, char **argv ) {
     // set default log levels
     sglog().setLogLevels( SG_ALL, SG_ALERT );
 
+    atexit(fgExitCleanup);
+
     string version;
 #ifdef FLIGHTGEAR_VERSION
     version = FLIGHTGEAR_VERSION;
@@ -1505,15 +1559,20 @@ bool fgMainInit( int argc, char **argv ) {
     fgInitFGRoot(argc, argv);
 
     // Check for the correct base package version
-    static char required_version[] = "0.9.4";
+    static char required_version[] = "0.9.5";
     string base_version = fgBasePackageVersion();
     if ( !(base_version == required_version) ) {
         // tell the operator how to use this application
 
+        SG_LOG( SG_GENERAL, SG_ALERT, "" ); // To popup the console on windows
         cerr << endl << "Base package check failed ... " \
              << "Found version " << base_version << " at: " \
              << globals->get_fg_root() << endl;
         cerr << "Please upgrade to version: " << required_version << endl;
+#ifdef _MSC_VER
+        cerr << "Hit a key to continue..." << endl;
+        cin.get();
+#endif
         exit(-1);
     }
 
@@ -1529,28 +1588,59 @@ bool fgMainInit( int argc, char **argv ) {
     }
 
     // Initialize the Window/Graphics environment.
-    if( !fgGlutInit(&argc, argv) ) {
-        SG_LOG( SG_GENERAL, SG_ALERT, "GLUT initialization failed ..." );
-        exit(-1);
-    }
+#if !defined(__APPLE__) || defined(OSX_BUNDLE)
+    // Mac OS X command line ("non-bundle") applications call this
+    // from main(), in bootstrap.cxx.  Andy doesn't know why, someone
+    // feel free to add comments...
+    fgOSInit(&argc, argv);
+#endif
 
-    // Initialize the various GLUT Event Handlers.
-    if( !fgGlutInitEvents() ) {
-        SG_LOG( SG_GENERAL, SG_ALERT, 
-        	"GLUT event handler initialization failed ..." );
-        exit(-1);
-    }
+    fgRegisterWindowResizeHandler( fgReshape );
+    fgRegisterIdleHandler( fgIdleFunction );
+    fgRegisterDrawHandler( fgRenderFrame );
+
+#ifdef FG_ENABLE_MULTIPASS_CLOUDS
+    bool get_stencil_buffer = true;
+#else
+    bool get_stencil_buffer = false;
+#endif
+
+    // Clouds3D requires an alpha channel
+    // clouds may require stencil buffer
+    fgOSOpenWindow( fgGetInt("/sim/startup/xsize"),
+                    fgGetInt("/sim/startup/ysize"),
+                    fgGetInt("/sim/rendering/bits-per-pixel"),
+                    fgGetBool("/sim/rendering/clouds3d"),
+                    get_stencil_buffer,
+                    fgGetBool("/sim/startup/fullscreen") );
+
+    // This seems to be the absolute earliest in the init sequence
+    // that these calls will return valid info.  Too bad it's after
+    // we've already created and sized out window. :-(
+    general.set_glVendor( (char *)glGetString ( GL_VENDOR ) );
+    general.set_glRenderer( (char *)glGetString ( GL_RENDERER ) );
+    general.set_glVersion( (char *)glGetString ( GL_VERSION ) );
+    SG_LOG( SG_GENERAL, SG_INFO, general.get_glRenderer() );
+
+    GLint tmp;
+    glGetIntegerv( GL_MAX_TEXTURE_SIZE, &tmp );
+    general.set_glMaxTexSize( tmp );
+    SG_LOG ( SG_GENERAL, SG_INFO, "Max texture size = " << tmp );
+
+    glGetIntegerv( GL_DEPTH_BITS, &tmp );
+    general.set_glDepthBits( tmp );
+    SG_LOG ( SG_GENERAL, SG_INFO, "Depth buffer bits = " << tmp );
 
     // Initialize plib net interface
     netInit( &argc, argv );
 
     // Initialize ssg (from plib).  Needs to come before we do any
-    // other ssg stuff, but after opengl/glut has been initialized.
+    // other ssg stuff, but after opengl has been initialized.
     ssgInit();
 
     // Initialize the user interface (we need to do this before
-    // passing off control to glut and before fgInitGeneral to get our
-    // fonts !!!
+    // passing off control to the OS main loop and before
+    // fgInitGeneral to get our fonts !!!
     guiInit();
 
     // Read the list of available aircrafts
@@ -1700,9 +1790,14 @@ bool fgMainInit( int argc, char **argv ) {
 
     // build our custom render states
     fgBuildRenderStates();
-    
-    // pass control off to the master GLUT event handler
-    glutMainLoop();
+
+    try {
+        // pass control off to the master event handler
+        fgOSMainLoop();
+    } catch (...) {
+        SG_LOG( SG_ALL, SG_ALERT,
+            "Unknown exception in the main loop. Aborting..." );
+    }
 
     // we never actually get here ... but to avoid compiler warnings,
     // etc.
