@@ -19,7 +19,7 @@
 // along with this program; if not, write to the Free Software
 // Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 //
-// $Id: viewmgr.cxx,v 1.10 2004/03/19 03:30:18 curt Exp $
+// $Id: viewmgr.cxx,v 1.11 2004/04/01 15:28:02 curt Exp $
 
 #include <string.h>		// strcmp
 
@@ -51,7 +51,8 @@ FGViewMgr::init ()
   bool at_model = false;
   int from_model_index = 0;
   int at_model_index = 0;
-  double damp_alt, damp_roll, damp_pitch, damp_heading;
+  // double damp_alt;
+  double damp_roll = 0.0, damp_pitch = 0.0, damp_heading = 0.0;
   double x_offset_m, y_offset_m, z_offset_m, fov_deg;
   double heading_offset_deg, pitch_offset_deg, roll_offset_deg;
   double target_x_offset_m, target_y_offset_m, target_z_offset_m;
