@@ -18,7 +18,7 @@
 // along with this program; if not, write to the Free Software
 // Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 //
-// $Id: native_ctrls.cxx,v 1.18 2004/01/12 17:39:44 curt Exp $
+// $Id: native_ctrls.cxx,v 1.21 2004/05/26 18:13:34 curt Exp $
 
 
 #ifdef HAVE_CONFIG_H
@@ -103,6 +103,8 @@ void FGProps2NetCtrls( FGNetCtrls *net, bool honor_freezes,
 {
     int i;
     SGPropertyNode *node;
+    SGPropertyNode *starter;
+    SGPropertyNode *fuelpump;
     SGPropertyNode *tempnode;
 
     // fill in values
@@ -121,7 +123,19 @@ void FGProps2NetCtrls( FGNetCtrls *net, bool honor_freezes,
     for ( i = 0; i < FGNetCtrls::FG_MAX_ENGINES; ++i ) {
         // Controls
         node = fgGetNode("/controls/engines/engine", i );
-	net->throttle[i] = node->getDoubleValue( "throttle", 0.0 );
+        starter = fgGetNode("/systems/electrical/outputs/starter", i );
+        fuelpump = fgGetNode("/systems/electrical/outputs/fuel-pump", i );
+
+        tempnode = node->getChild("master-bat");
+        if ( tempnode != NULL ) {
+            net->master_bat[i] = tempnode->getBoolValue();
+        }
+        tempnode = node->getChild("master-alt");
+        if ( tempnode != NULL ) {
+            net->master_alt[i] = tempnode->getBoolValue();
+        }
+
+        net->throttle[i] = node->getDoubleValue( "throttle", 0.0 );
 	net->mixture[i] = node->getDoubleValue( "mixture", 0.0 );
 	net->prop_advance[i] = node->getDoubleValue( "propeller-pitch", 0.0 );
 	net->magnetos[i] = node->getIntValue( "magnetos", 0 );
@@ -132,13 +146,18 @@ void FGProps2NetCtrls( FGNetCtrls *net, bool honor_freezes,
 	  // cout << "Starter -> " << node->getIntValue( "starter", false )
 	  //      << endl;
 	}
-	net->fuel_pump_power[i]
-            = node->getDoubleValue( "/systems/electrical/outputs/fuel-pump",
-                                    1.0 ) >= 1.0;
 
-	net->starter_power[i]
-            = node->getDoubleValue( "/systems/electrical/outputs/starter",
-                                    1.0 ) >= 1.0;
+        if ( fuelpump != NULL ) {
+            net->fuel_pump_power[i] = ( fuelpump->getDoubleValue() >= 1.0 );
+        } else {
+            net->fuel_pump_power[i] = 0.0;
+        }
+
+        if ( starter != NULL ) {
+            net->starter_power[i] = ( starter->getDoubleValue() >= 1.0 );
+        } else {
+            net->starter_power[i] = 0.0;
+        }
 
 	// Faults
 	SGPropertyNode *faults = node->getChild( "faults", 0, true );
@@ -169,15 +188,8 @@ void FGProps2NetCtrls( FGNetCtrls *net, bool honor_freezes,
     net->brake_right = node->getChild("brake-right")->getDoubleValue();
     net->brake_parking = node->getChild("brake-parking")->getDoubleValue();
 
-    node = fgGetNode("/controls/switches", true);
-    tempnode = node->getChild("master-bat");
-    if ( tempnode != NULL ) {
-        net->master_bat = tempnode->getBoolValue();
-    }
-    tempnode = node->getChild("master-alt");
-    if ( tempnode != NULL ) {
-        net->master_alt = tempnode->getBoolValue();
-    }
+    net->gear_handle = fgGetBool( "controls/gear/gear-down" );
+
     tempnode = node->getChild("master-avionics");
     if ( tempnode != NULL ) {
         net->master_avionics = tempnode->getBoolValue();
@@ -198,6 +210,9 @@ void FGProps2NetCtrls( FGNetCtrls *net, bool honor_freezes,
     // the user is switching views.
     net->hground = cur_fdm_state->get_ground_elev_ft() * SG_FEET_TO_METER;
     net->magvar = fgGetDouble("/environment/magnetic-variation-deg");
+
+    net->icing = fgGetDouble("/hazards/icing/wing");
+
     net->speedup = fgGetInt("/sim/speed-up");
     net->freeze = 0;
     if ( honor_freezes ) {
@@ -223,6 +238,8 @@ void FGProps2NetCtrls( FGNetCtrls *net, bool honor_freezes,
         net->flaps_power = htonl(net->flaps_power);
         net->flap_motor_ok = htonl(net->flap_motor_ok);
         for ( i = 0; i < FGNetCtrls::FG_MAX_ENGINES; ++i ) {
+            net->master_bat[i] = htonl(net->master_bat[i]);
+            net->master_alt[i] = htonl(net->master_alt[i]);
             net->magnetos[i] = htonl(net->magnetos[i]);
             net->starter_power[i] = htonl(net->starter_power[i]);
             htond(net->throttle[i]);
@@ -245,8 +262,6 @@ void FGProps2NetCtrls( FGNetCtrls *net, bool honor_freezes,
         htond(net->brake_right);
         htond(net->brake_parking);
         net->gear_handle = htonl(net->gear_handle);
-        net->master_bat = htonl(net->master_bat);
-        net->master_alt = htonl(net->master_alt);
         net->master_avionics = htonl(net->master_avionics);
         htond(net->wind_speed_kt);
         htond(net->wind_dir_deg);
@@ -255,6 +270,7 @@ void FGProps2NetCtrls( FGNetCtrls *net, bool honor_freezes,
         htond(net->press_inhg);
 	htond(net->hground);
         htond(net->magvar);
+        net->icing = htonl(net->icing);
         net->speedup = htonl(net->speedup);
         net->freeze = htonl(net->freeze);
     }
@@ -281,6 +297,8 @@ void FGNetCtrls2Props( FGNetCtrls *net, bool honor_freezes,
         net->flap_motor_ok = htonl(net->flap_motor_ok);
         net->num_engines = htonl(net->num_engines);
         for ( i = 0; i < net->num_engines; ++i ) {
+            net->master_bat[i] = htonl(net->master_bat[i]);
+            net->master_alt[i] = htonl(net->master_alt[i]);
             net->magnetos[i] = htonl(net->magnetos[i]);
             net->starter_power[i] = htonl(net->starter_power[i]);
             htond(net->throttle[i]);
@@ -302,8 +320,6 @@ void FGNetCtrls2Props( FGNetCtrls *net, bool honor_freezes,
         htond(net->brake_right);
         htond(net->brake_parking);
         net->gear_handle = htonl(net->gear_handle);
-        net->master_bat = htonl(net->master_bat);
-        net->master_alt = htonl(net->master_alt);
         net->master_avionics = htonl(net->master_avionics);
         htond(net->wind_speed_kt);
         htond(net->wind_dir_deg);
@@ -312,6 +328,7 @@ void FGNetCtrls2Props( FGNetCtrls *net, bool honor_freezes,
         htond(net->press_inhg);
         htond(net->hground);
         htond(net->magvar);
+        net->icing = htonl(net->icing);
         net->speedup = htonl(net->speedup);
         net->freeze = htonl(net->freeze);
     }
@@ -392,6 +409,8 @@ void FGNetCtrls2Props( FGNetCtrls *net, bool honor_freezes,
 
     // ground elevation ???
 
+    fgSetDouble("/hazards/icing/wing", net->icing);
+
     fgSetInt( "/sim/speed-up", net->speedup );
 
     if ( honor_freezes ) {
