@@ -18,7 +18,7 @@
 // along with this program; if not, write to the Free Software
 // Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 //
-// $Id: FGTileLoader.cxx,v 1.5 2004/03/18 02:37:01 curt Exp $
+// $Id: FGTileLoader.cxx,v 1.10 2004/06/08 15:32:09 ehofman Exp $
 
 #ifdef HAVE_CONFIG_H
 #  include <config.h>
@@ -40,7 +40,7 @@ extern ssgBranch *ground;
  */
 FGTileLoader::FGTileLoader()
 {
-#ifdef ENABLE_THREADS
+#if defined(ENABLE_THREADS) && ENABLE_THREADS
     // Create and start the loader threads.
     for (int i = 0; i < MAX_THREADS; ++i)
     {
@@ -55,7 +55,7 @@ FGTileLoader::FGTileLoader()
  */
 FGTileLoader::~FGTileLoader()
 {
-#ifdef ENABLE_THREADS
+#if defined(ENABLE_THREADS) && ENABLE_THREADS
     // Wake up its time to die.
     // queue_cond.broadcast();
 
@@ -88,20 +88,12 @@ FGTileLoader::add( FGTileEntry* tile )
 {
     /**
      * Initialise tile_path here and not in ctor to avoid problems
-     * with the initialastion order of global objects.
+     * with the initialisation order of global objects.
      */
     static bool beenhere = false;
-    if (!beenhere)
-    {
-	if ( !globals->get_fg_scenery().empty() ) {
-            tile_path = globals->get_fg_scenery();
-	} else {
-            SGPath tmp;
-	    tmp.set( globals->get_fg_root() );
-            tmp.append( "Scenery" );
-            tile_path = tmp.str();
-	}
-	beenhere = true;
+    if (!beenhere) {
+        tile_path = globals->get_fg_scenery();
+        beenhere = true;
     }
 
     tile_load_queue.push( tile );
@@ -125,7 +117,7 @@ void
 FGTileLoader::update()
 {
 
-#ifdef ENABLE_THREADS
+#if defined(ENABLE_THREADS) && ENABLE_THREADS
     // send a signal to the pager thread that it is allowed to load
     // another tile
     mutex.lock();
@@ -159,7 +151,7 @@ FGTileLoader::update()
 }
 
 
-#ifdef ENABLE_THREADS
+#if defined(ENABLE_THREADS) && ENABLE_THREADS
 /**
  * 
  */
