@@ -18,7 +18,7 @@
 // along with this program; if not, write to the Free Software
 // Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 //
-// $Id: tileentry.cxx,v 1.34 2003/12/30 15:12:04 curt Exp $
+// $Id: tileentry.cxx,v 1.36 2004/06/08 15:32:09 ehofman Exp $
 
 
 #ifdef HAVE_CONFIG_H
@@ -662,29 +662,24 @@ bool FGTileEntry::obj_load( const string& path,
 
 
 void
-FGTileEntry::load( const string &base_path, bool is_base )
+FGTileEntry::load( const string_list &path_list, bool is_base )
 {
-    SG_LOG( SG_TERRAIN, SG_INFO, "load() base search path = "
-            << base_path );
-
     bool found_tile_base = false;
 
-    string_list search = sgPathSplit( base_path );
-
     // obj_load() will generate ground lighting for us ...
     ssgVertexArray *light_pts = new ssgVertexArray( 100 );
 
     ssgBranch* new_tile = new ssgBranch;
 
     unsigned int i = 0;
-    while ( i < search.size() ) {
+    while ( i < path_list.size() ) {
 
         bool has_base = false;
 
         // Generate names for later use
         string index_str = tile_bucket.gen_index_str();
 
-        SGPath tile_path = search[i];
+        SGPath tile_path = path_list[i];
         tile_path.append( tile_bucket.gen_base_path() );
 
         SGPath basename = tile_path;
@@ -725,6 +720,9 @@ FGTileEntry::load( const string &base_path, bool is_base )
                                        geometry, NULL, NULL, NULL, light_pts,
                                        true ) )
                             {
+                                geometry->getKid( 0 )->setTravCallback( 
+                                                        SSG_CALLBACK_PRETRAV,
+                                                        &FGTileMgr::tile_filter_cb );
                                 new_tile -> addKid( geometry );
                             } else {
                                 delete geometry;
@@ -752,6 +750,9 @@ FGTileEntry::load( const string &base_path, bool is_base )
                                        taxi_lights, NULL, false ) )
                             {
                                 if ( geometry -> getNumKids() > 0 ) {
+                                    geometry->getKid( 0 )->setTravCallback(
+                                                                SSG_CALLBACK_PRETRAV,
+                                                                &FGTileMgr::tile_filter_cb );
                                     new_tile -> addKid( geometry );
                                 } else {
                                     delete geometry;
@@ -912,7 +913,7 @@ FGTileEntry::load( const string &base_path, bool is_base )
         ssgBranch *geometry = new ssgBranch;
         Point3D c;
         double br;
-        if ( sgGenTile( search[0], tile_bucket, &c, &br,
+        if ( sgGenTile( path_list[0], tile_bucket, &c, &br,
                         globals->get_matlib(), geometry ) )
         {
             center = c;
