@@ -18,7 +18,7 @@
 // along with this program; if not, write to the Free Software
 // Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 //
-// $Id: tilemgr.cxx,v 1.35 2004/03/20 22:42:41 ehofman Exp $
+// $Id: tilemgr.cxx,v 1.40 2004/07/22 16:42:14 ehofman Exp $
 
 
 #ifdef HAVE_CONFIG_H
@@ -46,7 +46,7 @@
 
 #define TEST_LAST_HIT_CACHE
 
-#ifdef ENABLE_THREADS
+#if defined(ENABLE_THREADS) && ENABLE_THREADS
 SGLockedQueue<FGTileEntry *> FGTileMgr::attach_queue;
 SGLockedQueue<FGDeferredModel *> FGTileMgr::model_queue;
 #else
@@ -55,13 +55,13 @@ queue<FGDeferredModel *> FGTileMgr::model_queue;
 #endif // ENABLE_THREADS
 queue<FGTileEntry *> FGTileMgr::delete_queue;
 
+bool FGTileMgr::tile_filter = true;
 
 // Constructor
 FGTileMgr::FGTileMgr():
     state( Start ),
     current_tile( NULL ),
-    vis( 16000 ),
-    counter_hack(0)
+    vis( 16000 )
 {
 }
 
@@ -89,7 +89,7 @@ int FGTileMgr::init() {
     }
 
     while ( ! model_queue.empty() ) {
-#ifdef ENABLE_THREADS
+#if defined(ENABLE_THREADS) && ENABLE_THREADS
         FGDeferredModel* dm = model_queue.pop();
 #else
         FGDeferredModel* dm = model_queue.front();
@@ -261,6 +261,15 @@ void FGTileMgr::initialize_queue()
 #endif
 }
 
+/**
+ * return current status of queues
+ *
+ */
+
+bool FGTileMgr::all_queues_empty() {
+	return attach_queue.empty() && model_queue.empty();
+}
+
 
 /**
  * Update the various queues maintained by the tilemagr (private
@@ -274,7 +283,7 @@ void FGTileMgr::update_queues()
     if ( !model_queue.empty() ) {
         // cout << "loading next model ..." << endl;
         // load the next tile in the queue
-#ifdef ENABLE_THREADS
+#if defined(ENABLE_THREADS) && ENABLE_THREADS
         FGDeferredModel* dm = model_queue.pop();
 #else
         FGDeferredModel* dm = model_queue.front();
@@ -304,16 +313,11 @@ void FGTileMgr::update_queues()
     
     // cout << "current elevation (ssg) == " << scenery.get_cur_elev() << endl;
 
-    // activate loader thread one out of every 5 frames
-    if ( counter_hack == 0 ) {
-        // Notify the tile loader that it can load another tile
-        loader.update();
-    } else {
-        counter_hack = (counter_hack + 1) % 5;
-    }
+    // Notify the tile loader that it can load another tile
+    loader.update();
 
     if ( !attach_queue.empty() ) {
-#ifdef ENABLE_THREADS
+#if defined(ENABLE_THREADS) && ENABLE_THREADS
         FGTileEntry* e = attach_queue.pop();
 #else
         FGTileEntry* e = attach_queue.front();
@@ -512,3 +516,13 @@ void FGTileMgr::prep_ssg_nodes( SGLocation *location, float vis ) {
     }
 }
 
+bool FGTileMgr::set_tile_filter( bool f ) {
+    bool old = tile_filter;
+    tile_filter = f;
+    return old;
+}
+
+int FGTileMgr::tile_filter_cb( ssgEntity *, int )
+{
+  return tile_filter ? 1 : 0;
+}
