@@ -19,7 +19,7 @@
 // along with this program; if not, write to the Free Software
 // Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 //
-// $Id: fg_fx.cxx,v 1.8 2003/09/24 17:20:57 ehofman Exp $
+// $Id: fg_fx.cxx,v 1.10 2004/05/14 15:51:43 curt Exp $
 
 #ifdef _MSC_VER
 #pragma warning (disable: 4786)
@@ -32,14 +32,16 @@
 #endif
 #include <simgear/misc/sg_path.hxx>
 #include <simgear/props/props.hxx>
-#include <simgear/sound/sound.hxx>
+#include <simgear/sound/xmlsound.hxx>
 
 #include <Main/fg_props.hxx>
 
 #include "fg_fx.hxx"
 
 
-FGFX::FGFX ()
+FGFX::FGFX () :
+    last_pause( true ),
+    last_volume( 0.0 )
 {
 }
 
@@ -51,7 +53,7 @@ FGFX::~FGFX ()
 void
 FGFX::init()
 {
-   SGPropertyNode * node = fgGetNode("/sim/sound", true);
+   SGPropertyNode *node = fgGetNode("/sim/sound", true);
    int i;
 
    string path_str = node->getStringValue("path");
@@ -76,7 +78,7 @@ FGFX::init()
 
    node = root.getNode("fx");
    for (i = 0; i < node->nChildren(); i++) {
-      SGSound *sound = new SGSound();
+      SGXmlSound *sound = new SGXmlSound();
 
       sound->init(globals->get_props(), node->getChild(i),
                   globals->get_soundmgr(), globals->get_fg_root());
@@ -105,9 +107,28 @@ FGFX::unbind ()
 void
 FGFX::update (double dt)
 {
-    if (fgGetBool("/sim/sound/audible")) {
-        for (unsigned int i = 0; i < _sound.size(); i++ )
+    // command sound manger
+    bool pause = fgGetBool("/sim/sound/pause");
+    if ( pause != last_pause ) {
+        if ( pause ) {
+            globals->get_soundmgr()->pause();
+        } else {
+            globals->get_soundmgr()->resume();
+        }
+        last_pause = pause;
+    }
+
+    double volume = fgGetDouble("/sim/sound/volume");
+    if ( volume != last_volume ) {
+        globals->get_soundmgr()->set_volume( volume );        
+        last_volume = volume;
+    }
+
+    if ( !pause ) {
+        // update sound effects if not paused
+        for ( unsigned int i = 0; i < _sound.size(); i++ ) {
             _sound[i]->update(dt);
+        }
     }
 }
 
